package com.extensibility.validation;

import com.extensibility.dom.DOMUtilities;
import com.extensibility.util.HashVector;
import com.extensibility.xml.SXE;
import java.util.Enumeration;
import java.util.Vector;

public class ValidatorErrorList implements ValidatorErrorTags {
   protected HashVector errorMap = new HashVector();
   protected int count = 0;
   protected boolean dirty = false;

   public synchronized void add(ValidatorError var1) {
      this.errorMap.put(var1.getErrorLocation(), var1);
      ++this.count;
      this.dirty = true;
   }

   public synchronized Vector getList(Object var1) {
      return this.errorMap.getVector(var1);
   }

   public synchronized void remove(Object var1) {
      Vector var2 = this.errorMap.getVector(var1);
      if (var2 != null) {
         this.count -= var2.size();
         this.errorMap.remove(var1);
         this.dirty = true;
      }

   }

   public Enumeration errors() {
      return this.errorMap.subelements();
   }

   public synchronized void clear() {
      if (this.count != 0) {
         this.dirty = true;
      }

      this.errorMap.clear();
      this.count = 0;
   }

   public int size() {
      return this.count;
   }

   public boolean isDirty() {
      return this.dirty;
   }

   public void clearDirty() {
      this.dirty = false;
   }

   public static void writeAsXML(ValidatorErrorList var0, SXE var1) {
      var1.writeElem("errorList");
      Enumeration var2 = var0.errors();

      while(var2.hasMoreElements()) {
         ValidatorError var3 = (ValidatorError)var2.nextElement();
         var1.writeElem("error", -1);
         var1.writeElem("node", -1);
         var1.writeText(DOMUtilities.getXPath(var3.getErrorNode()));
         var1.flush("node");
         var1.writeElem("message", -1);
         var1.writeText(var3.getMessage());
         var1.flush("message");
         var1.flush("error");
      }

      var1.flush("errorList");
      var1.flush();
   }
}
